@@ -1,6 +1,6 @@
 package SPVM::Resource::Eigen;
 
-our $VERSION = "0.002";
+our $VERSION = "0.003";
 
 1;
 
@@ -20,6 +20,13 @@ MyClass.config:
   
   $config->use_resource('Resource::Eigen');
   
+  if ($^O eq 'MSWin32') {
+    $config->add_static_lib('stdc++');
+  }
+  else {
+    $config->add_lib('stdc++');
+  }
+  
   $config;
 
 MyClass.cpp:
@@ -56,6 +63,24 @@ C++
 
 C++17
 
+=head1 Required Libraries
+
+Windows:
+
+=over 2
+
+=item * stdc++ (The static link is preffered)
+
+=back
+
+Unix/Linux/Mac:
+
+=over 2
+
+=item * stdc++
+
+=back
+
 =head1 Header Files
 
   Eigen/Cholesky
